ADJECTIVES = [
    "aristotelian",
    "arthurian",
    "bohemian",
    "brethren",
    "mosaic",
    "pceanic",
    "proctor",
    "terran",
    "tudor",
    "abroad",
    "absorbing",
    "abstract",
    "academic",
    "accelerated",
    "accented",
    "accountant",
    "acquainted",
    "acute",
    "addicting",
    "addictive",
    "adjustable",
    "admired",
    "adult",
    "adverse",
    "advised",
    "aerosol",
    "afraid",
    "aggravated",
    "aggressive",
    "agreeable",
    "alienate",
    "aligned",
    "alleged",
    "almond",
    "alright",
    "altruistic",
    "ambient",
    "ambivalent",
    "amiable",
    "amino",
    "amorphous",
    "amused",
    "anatomical",
    "ancestral",
    "angelic",
    "angrier",
    "answerable",
    "antiquarian",
    "antiretroviral",
    "appellate",
    "applicable",
    "apportioned",
    "approachable",
    "appropriated",
    "archer",
    "aroused",
    "arrested",
    "assertive",
    "assigned",
    "athletic",
    "atrocious",
    "attained",
    "authoritarian",
    "autobiographical",
    "avaricious",
    "avocado",
    "awake",
    "awsome",
    "backstage",
    "backwoods",
    "balding",
    "bandaged",
    "banded",
    "banned",
    "barreled",
    "battle",
    "beaten",
    "begotten",
    "beguiled",
    "bellied",
    "belted",
    "beneficent",
    "besieged",
    "betting",
    "biggest",
    "biochemical",
    "bipolar",
    "blackened",
    "blame",
    "blessed",
    "blindfolded",
    "bloat",
    "blocked",
    "blooded",
    "blushing",
    "boastful",
    "bolder",
    "bolstered",
    "bonnie",
    "bored",
    "boundary",
    "bounded",
    "bounding",
    "branched",
    "brawling",
    "brazen",
    "breeding",
    "bridged",
    "brimming",
    "brimstone",
    "broadest",
    "broiled",
    "broker",
    "bronze",
    "bruising",
    "buffy",
    "bullied",
    "bungling",
    "burial",
    "buttery",
    "candied",
    "canonical",
    "cantankerous",
    "cardinal",
    "carefree",
    "caretaker",
    "casual",
    "cathartic",
    "causal",
    "chapel",
    "characterized",
    "charcoal",
    "cheeky",
    "cherished",
    "chipotle",
    "chirping",
    "chivalrous",
    "circumstantial",
    "civic",
    "civil",
    "civilised",
    "clanking",
    "clapping",
    "claptrap",
    "classless",
    "cleansed",
    "cleric",
    "cloistered",
    "codified",
    "colloquial",
    "colour",
    "combat",
    "combined",
    "comely",
    "commissioned",
    "commonplace",
    "commuter",
    "commuting",
    "comparable",
    "complementary",
    "compromising",
    "conceding",
    "concentrated",
    "conceptual",
    "conditioned",
    "confederate",
    "confident",
    "confidential",
    "confining",
    "confuse",
    "congressional",
    "consequential",
    "conservative",
    "constituent",
    "contaminated",
    "contemporaneous",
    "contraceptive",
    "convertible",
    "convex",
    "cooked",
    "coronary",
    "corporatist",
    "correlated",
    "corroborated",
    "cosmic",
    "cover",
    "crash",
    "crypto",
    "culminate",
    "cushioned",
    "dandy",
    "dashing",
    "dazzled",
    "decreased",
    "decrepit",
    "dedicated",
    "defaced",
    "defective",
    "defenseless",
    "deluded",
    "deodorant",
    "departed",
    "depress",
    "designing",
    "despairing",
    "destitute",
    "detective",
    "determined",
    "devastating",
    "deviant",
    "devilish",
    "devoted",
    "diagonal",
    "dictated",
    "didactic",
    "differentiated",
    "diffused",
    "dirtier",
    "disabling",
    "disconnected",
    "discovered",
    "disdainful",
    "diseased",
    "disfigured",
    "disheartened",
    "disheveled",
    "disillusioned",
    "disparate",
    "dissident",
    "doable",
    "doctrinal",
    "doing",
    "dotted",
    "downbeat",
    "dozen",
    "draining",
    "draught",
    "dread",
    "dried",
    "dropped",
    "dulled",
    "duplicate",
    "eaten",
    "echoing",
    "economical",
    "elaborated",
    "elastic",
    "elective",
    "electoral",
    "elven",
    "embryo",
    "emerald",
    "emergency",
    "emissary",
    "emotional",
    "employed",
    "enamel",
    "encased",
    "encrusted",
    "endangered",
    "engraved",
    "engrossing",
    "enlarged",
    "enlisted",
    "enlivened",
    "ensconced",
    "entangled",
    "enthralling",
    "entire",
    "envious",
    "eradicated",
    "eroded",
    "esoteric",
    "essential",
    "evaporated",
    "evergreen",
    "everlasting",
    "exacting",
    "exasperated",
    "excess",
    "exciting",
    "executable",
    "existent",
    "exonerated",
    "exorbitant",
    "exponential",
    "export",
    "extraordinary",
    "exultant",
    "exulting",
    "facsimile",
    "fading",
    "fainter",
    "fallacious",
    "faltering",
    "famous",
    "fancier",
    "fated",
    "favourable",
    "fearless",
    "feathered",
    "fellow",
    "fermented",
    "ferocious",
    "fiddling",
    "filling",
    "firmer",
    "fitted",
    "flammable",
    "flawed",
    "fledgling",
    "fleshy",
    "flexible",
    "flickering",
    "floral",
    "flowering",
    "flowing",
    "foggy",
    "folic",
    "foolhardy",
    "foolish",
    "footy",
    "forehand",
    "forked",
    "formative",
    "formulaic",
    "fractional",
    "fragrant",
    "fraudulent",
    "freakish",
    "freckled",
    "freelance",
    "freight",
    "fresh",
    "fretted",
    "frugal",
    "fulfilling",
    "fuming",
    "funded",
    "funny",
    "garbled",
    "gathered",
    "geologic",
    "geometric",
    "gibberish",
    "gilded",
    "ginger",
    "glare",
    "glaring",
    "gleaming",
    "glorified",
    "glorious",
    "goalless",
    "goody",
    "grammatical",
    "grande",
    "grateful",
    "gratuitous",
    "graven",
    "greener",
    "grinding",
    "grizzly",
    "groaning",
    "grudging",
    "guaranteed",
    "gusty",
    "halfbreed",
    "handheld",
    "handheld",
    "handsoff",
    "hardpressed",
    "harlot",
    "healing",
    "healthier",
    "healthiest",
    "heart",
    "heartshaped",
    "heathen",
    "hedonistic",
    "heralded",
    "herbal",
    "highdensity",
    "highperformance",
    "highres",
    "highyield",
    "hissy",
    "hitless",
    "holiness",
    "homesick",
    "honorable",
    "hooded",
    "hopeless",
    "horrendous",
    "horrible",
    "hotbutton",
    "huddled",
    "human",
    "humbling",
    "humid",
    "humiliating",
    "hypnotized",
    "idealistic",
    "idiosyncratic",
    "ignited",
    "illustrated",
    "illustrative",
    "imitated",
    "immense",
    "immersive",
    "immigrant",
    "immoral",
    "impassive",
    "impressionable",
    "improbable",
    "impulsive",
    "in-flight",
    "inattentive",
    "inbound",
    "inbounds",
    "incalculable",
    "incomprehensible",
    "indefatigable",
    "indigo",
    "indiscriminate",
    "indomitable",
    "inert",
    "inflate",
    "inform",
    "inheriting",
    "injured",
    "injurious",
    "inking",
    "inoffensive",
    "insane",
    "insensible",
    "insidious",
    "insincere",
    "insistent",
    "insolent",
    "insufferable",
    "intemperate",
    "interdependent",
    "interesting",
    "interfering",
    "intern",
    "interpreted",
    "intersecting",
    "intolerable",
    "intolerant",
    "intuitive",
    "irresolute",
    "irritate",
    "jealous",
    "jerking",
    "joining",
    "joint",
    "journalistic",
    "joyful",
    "keyed",
    "knowing",
    "lacklustre",
    "laden",
    "lagging",
    "lamented",
    "laughable",
    "layered",
    "leather",
    "leathern",
    "leery",
    "legible",
    "leisure",
    "lessening",
    "liberating",
    "lifesize",
    "lifted",
    "lightest",
    "limitless",
    "listening",
    "literary",
    "liver",
    "livid",
    "lobster",
    "locked",
    "longheld",
    "longlasting",
    "longrunning",
    "longsuffering",
    "loudest",
    "loveliest",
    "lowbudget",
    "lowcarb",
    "lowering",
    "lucid",
    "luckless",
    "lusty",
    "luxurious",
    "magazine",
    "maniac",
    "manmade",
    "maroon",
    "mastered",
    "mated",
    "material",
    "materialistic",
    "meaningful",
    "measuring",
    "mediaeval",
    "medical",
    "meditated",
    "medley",
    "melodic",
    "memorable",
    "memorial",
    "metabolic",
    "metallic",
    "metallurgical",
    "metering",
    "midair",
    "midterm",
    "midway",
    "mighty",
    "migrating",
    "mindblowing",
    "mindboggling",
    "minor",
    "mirrored",
    "misguided",
    "misshapen",
    "mitigated",
    "mixed",
    "modernized",
    "molecular",
    "monarch",
    "monastic",
    "morbid",
    "motley",
    "motorized",
    "mounted",
    "multidisciplinary",
    "muscled",
    "muscular",
    "muted",
    "mysterious",
    "mythic",
    "nailbiting",
    "natural",
    "nauseous",
    "negative",
    "networked",
    "neurological",
    "neutered",
    "newest",
    "night",
    "nitrous",
    "nofly",
    "noncommercial",
    "nonsense",
    "north",
    "nuanced",
    "occurring",
    "offensive",
    "oldest",
    "oncoming",
    "one-year",
    "onstage",
    "onward",
    "opaque",
    "operating",
    "opportunist",
    "opposing",
    "ordinate",
    "outdone",
    "outlaw",
    "outsized",
    "overboard",
    "overheated",
    "oversize",
    "overworked",
    "oyster",
    "paced",
    "panting",
    "paralyzed",
    "paramount",
    "parental",
    "parted",
    "partisan",
    "passive",
    "pastel",
    "patriot",
    "peacekeeping",
    "pedestrian",
    "peevish",
    "penal",
    "penned",
    "pensive",
    "perceptual",
    "perky",
    "permissible",
    "pernicious",
    "perpetuate",
    "perplexed",
    "pervasive",
    "petrochemical",
    "philosophical",
    "picturesque",
    "pillaged",
    "piped",
    "piquant",
    "pitching",
    "plausible",
    "pliable",
    "plumb",
    "politician",
    "polygamous",
    "poorest",
    "portmanteau",
    "posed",
    "positive",
    "possible",
    "postpartum",
    "prank",
    "precocious",
    "predicted",
    "premium",
    "preparatory",
    "prerequisite",
    "prescient",
    "preserved",
    "presidential",
    "pressed",
    "pressurized",
    "presumed",
    "prewar",
    "priced",
    "pricier",
    "primal",
    "primer",
    "primetime",
    "printed",
    "private",
    "problem",
    "procedural",
    "process",
    "prodigious",
    "professional",
    "programmed",
    "progressive",
    "prolific",
    "promising",
    "promulgated",
    "pronged",
    "proportionate",
    "protracted",
    "pulled",
    "pulsed",
    "purgatory",
    "quick",
    "raunchy",
    "razed",
    "reactive",
    "readable",
    "realizing",
    "recognised",
    "recovering",
    "recurrent",
    "recycled",
    "redeemable",
    "reflecting",
    "regal",
    "registering",
    "reliable",
    "reminiscent",
    "remorseless",
    "removable",
    "renewable",
    "repeating",
    "repellent",
    "reserve",
    "resigned",
    "respectful",
    "rested",
    "restrict",
    "resultant",
    "retaliatory",
    "retiring",
    "revelatory",
    "reverend",
    "reversing",
    "revolving",
    "ridiculous",
    "ringed",
    "risque",
    "robust",
    "roomful",
    "rotating",
    "roused",
    "rubber",
    "running",
    "runtime",
    "rustling",
    "safest",
    "salient",
    "sanctioned",
    "saute",
    "saved",
    "scandalized",
    "scarlet",
    "scattering",
    "sceptical",
    "scheming",
    "scoundrel",
    "scratched",
    "scratchy",
    "scrolled",
    "seated",
    "secondbest",
    "segregated",
    "selftaught",
    "semiautomatic",
    "senior",
    "sensed",
    "sentient",
    "sexier",
    "shadowy",
    "shaken",
    "shaker",
    "shameless",
    "shaped",
    "shiny",
    "shipped",
    "shivering",
    "shoestring",
    "short",
    "shortlived",
    "signed",
    "simplest",
    "simplistic",
    "sizable",
    "skeleton",
    "skinny",
    "skirting",
    "skyrocketed",
    "slamming",
    "slanting",
    "slapstick",
    "sleek",
    "sleepless",
    "sleepy",
    "slender",
    "slimmer",
    "smacking",
    "smokeless",
    "smothered",
    "smouldering",
    "snuff",
    "socialized",
    "solidstate",
    "sometime",
    "sought",
    "spanking",
    "sparing",
    "spattered",
    "specialized",
    "specific",
    "speedy",
    "spherical",
    "spiky",
    "spineless",
    "sprung",
    "squint",
    "stainless",
    "standing",
    "starlight",
    "startled",
    "stately",
    "statewide",
    "stereoscopic",
    "sticky",
    "stimulant",
    "stinky",
    "stoked",
    "stolen",
    "storied",
    "strained",
    "strapping",
    "strengthened",
    "stubborn",
    "stylized",
    "suave",
    "subjective",
    "subjugated",
    "subordinate",
    "succeeding",
    "suffering",
    "summary",
    "sunset",
    "sunshine",
    "supernatural",
    "supervisory",
    "supplyside",
    "surrogate",
    "suspended",
    "suspenseful",
    "swarthy",
    "sweating",
    "sweeping",
    "swinging",
    "swooning",
    "sympathize",
    "synchronized",
    "synonymous",
    "synthetic",
    "tailed",
    "tallest",
    "tangible",
    "tanked",
    "tarry",
    "technical",
    "tectonic",
    "telepathic",
    "tenderest",
    "territorial",
    "testimonial",
    "theistic",
    "thicker",
    "threatening",
    "tightlipped",
    "timed",
    "timely",
    "timid",
    "torrent",
    "totalled",
    "tougher",
    "traditional",
    "transformed",
    "trapped",
    "traveled",
    "traverse",
    "treated",
    "trial",
    "trunk",
    "trusting",
    "trying",
    "twisted",
    "twolane",
    "tyrannical",
    "unaided",
    "unassisted",
    "unassuming",
    "unattractive",
    "uncapped",
    "uncomfortable",
    "uncontrolled",
    "uncooked",
    "uncooperative",
    "underground",
    "undersea",
    "undisturbed",
    "unearthly",
    "uneasy",
    "unequal",
    "unfazed",
    "unfinished",
    "unforeseen",
    "unforgivable",
    "unidentified",
    "unimaginative",
    "uninspired",
    "unintended",
    "uninvited",
    "universal",
    "unmasked",
    "unorthodox",
    "unparalleled",
    "unpleasant",
    "unprincipled",
    "unread",
    "unreasonable",
    "unregulated",
    "unreliable",
    "unremitting",
    "unsafe",
    "unsanitary",
    "unsealed",
    "unsuccessful",
    "unsupervised",
    "untimely",
    "unwary",
    "unwrapped",
    "uppity",
    "upstart",
    "useless",
    "utter",
    "valiant",
    "valid",
    "valued",
    "vanilla",
    "vaulting",
    "vaunted",
    "veering",
    "vegetative",
    "vented",
    "verbal",
    "verifying",
    "veritable",
    "versed",
    "vinyl",
    "virgin",
    "visceral",
    "visual",
    "voluptuous",
    "walkon",
    "wanton",
    "warlike",
    "washed",
    "waterproof",
    "waved",
    "weakest",
    "wellbred",
    "wellchosen",
    "wellinformed",
    "wetting",
    "wheeled",
    "whirlwind",
    "widen",
    "widening",
    "willful",
    "willing",
    "winnable",
    "winningest",
    "wireless",
    "wistful",
    "woeful",
    "wooded",
    "woodland",
    "wordless",
    "workable",
    "worldly",
    "worldwide",
    "worstcase",
    "worsted",
    "worthless",
    "abandoned",
    "abused",
    "accepted",
    "accomplished",
    "accusatory",
    "accused",
    "adored",
    "adrift",
    "affectionate",
    "agitated",
    "alarmed",
    "alert",
    "alienated",
    "alive",
    "alluring",
    "alone",
    "aloof",
    "amazed",
    "ambushed",
    "angry",
    "annoyed",
    "antagonistic",
    "anxious",
    "apathetic",
    "apologetic",
    "appalled",
    "appreciated",
    "appreciative",
    "apprehensive",
    "ashamed",
    "astonished",
    "attacked",
    "attractive",
    "aware",
    "awe",
    "awed",
    "awestruck",
    "awkward",
    "bad",
    "baffled",
    "barren",
    "bashful",
    "belittled",
    "benevolent",
    "berated",
    "betrayed",
    "bewildered",
    "bitchy",
    "bitter",
    "bittersweet",
    "blah",
    "blamed",
    "blank",
    "blissful",
    "blue",
    "bold",
    "bothered",
    "bouncy",
    "brave",
    "broken",
    "brooding",
    "bummed",
    "burdened",
    "burned",
    "callous",
    "calm",
    "capable",
    "careless",
    "caring",
    "caustic",
    "cautious",
    "censored",
    "centered",
    "certain",
    "challenged",
    "charmed",
    "cheated",
    "cheerful",
    "childish",
    "chipper",
    "choleric",
    "clean",
    "clear",
    "clever",
    "close",
    "closed",
    "clueless",
    "clumsy",
    "cold",
    "comfortable",
    "committed",
    "compassionate",
    "competent",
    "competitive",
    "complacent",
    "complete",
    "concerned",
    "condemned",
    "condescension",
    "confused",
    "considerate",
    "contemplative",
    "contempt",
    "contemptuous",
    "content",
    "controlled",
    "conventional",
    "convicted",
    "cornered",
    "courageous",
    "cowardly",
    "cranky",
    "crappy",
    "crazy",
    "critical",
    "cross",
    "crushed",
    "curious",
    "cynical",
    "daring",
    "dark",
    "dashed",
    "dazed",
    "dead",
    "deceived",
    "defeated",
    "defensive",
    "defiant",
    "degraded",
    "dejected",
    "delicate",
    "delighted",
    "demoralized",
    "dependent",
    "depressed",
    "deprived",
    "derisive",
    "deserted",
    "desired",
    "desolate",
    "despair",
    "desperate",
    "destroyed",
    "detached",
    "devastated",
    "devious",
    "different",
    "difficult",
    "dignified",
    "dirty",
    "disappointed",
    "disbelieving",
    "discarded",
    "discontent",
    "discontented",
    "discouraged",
    "disgraced",
    "disgusted",
    "dishonest",
    "dismal",
    "dismayed",
    "disobedient",
    "disorganized",
    "disposable",
    "distant",
    "distracted",
    "distressed",
    "disturbed",
    "ditzy",
    "dorky",
    "doubtful",
    "down",
    "drained",
    "dreamy",
    "dreary",
    "drunk",
    "dull",
    "dumb",
    "eager",
    "earnest",
    "ecstatic",
    "edgy",
    "effective",
    "elated",
    "embarassed",
    "embarrassed",
    "empathetic",
    "empowered",
    "empty",
    "enchanted",
    "encouraged",
    "energetic",
    "energized",
    "enlightened",
    "enraged",
    "enriched",
    "entertained",
    "enthralled",
    "enthusiastic",
    "erudite",
    "evasive",
    "evil",
    "excited",
    "excluded",
    "exhausted",
    "exhilarated",
    "expectant",
    "exploited",
    "exposed",
    "exuberant",
    "faithful",
    "fake",
    "fanciful",
    "fantastic",
    "fatalistic",
    "fatigued",
    "fearful",
    "feisty",
    "fine",
    "flirty",
    "flustered",
    "foreboding",
    "forgiven",
    "forgiving",
    "forgotten",
    "forthright",
    "fortunate",
    "framed",
    "frantic",
    "free",
    "friendly",
    "frightened",
    "frisky",
    "frustrated",
    "fulfilled",
    "full",
    "furious",
    "futile",
    "geeky",
    "generous",
    "gentle",
    "giddy",
    "giggly",
    "giving",
    "glad",
    "gloomy",
    "good",
    "great",
    "grieving",
    "groggy",
    "grouchy",
    "grumpy",
    "guarded",
    "guilty",
    "gullible",
    "handicapped",
    "happy",
    "harmonious",
    "hateful",
    "haughty",
    "haunted",
    "haunting",
    "healthy",
    "heard",
    "heartbroken",
    "helpful",
    "helpless",
    "hesitant",
    "high",
    "honored",
    "hopeful",
    "horrified",
    "hospitable",
    "hostile",
    "hot",
    "humble",
    "humiliated",
    "hungry",
    "hurt",
    "hyper",
    "hysterical",
    "idiotic",
    "idyllic",
    "ignorant",
    "ignored",
    "imaginative",
    "immune",
    "impatient",
    "impelled",
    "imperfect",
    "impertinent",
    "important",
    "impressed",
    "inadequate",
    "incensed",
    "inclusive",
    "incompetent",
    "incomplete",
    "incredulous",
    "indebted",
    "indecisive",
    "independent",
    "indescribable",
    "indifferent",
    "indignant",
    "industrious",
    "inept",
    "inferior",
    "inflated",
    "informed",
    "infuriated",
    "inhibited",
    "innocent",
    "innovative",
    "inquisitive",
    "insecure",
    "insensitive",
    "insignificant",
    "insulted",
    "intense",
    "interested",
    "interrogated",
    "interrupted",
    "intimate",
    "intimidated",
    "intrigued",
    "invigorated",
    "invisible",
    "involved",
    "irate",
    "irked",
    "irrational",
    "irresponsible",
    "irritated",
    "isolated",
    "jaded",
    "jinxed",
    "jolly",
    "jovial",
    "joyous",
    "jubilant",
    "judged",
    "judgmental",
    "jumpy",
    "just",
    "justified",
    "kidded",
    "kind",
    "knowledgeable",
    "late",
    "lazy",
    "left",
    "let",
    "lethargic",
    "liable",
    "liberated",
    "lifeless",
    "liked",
    "listened",
    "listless",
    "logical",
    "lonely",
    "loose",
    "lost",
    "lousy",
    "lovable",
    "loved",
    "loving",
    "lucky",
    "lyrical",
    "mad",
    "malicious",
    "manipulated",
    "matter",
    "fact",
    "mean",
    "meditative",
    "melancholic",
    "melancholy",
    "mellow",
    "merciless",
    "merry",
    "mischievous",
    "miserable",
    "misinterpreted",
    "mistreated",
    "misunderstood",
    "mocked",
    "mocking",
    "modest",
    "molested",
    "moody",
    "morose",
    "motivated",
    "mournful",
    "moved",
    "mystified",
    "naive",
    "nasty",
    "naughty",
    "nauseated",
    "needed",
    "needy",
    "neglected",
    "nerdy",
    "nervous",
    "neurotic",
    "nightmarish",
    "nonchalant",
    "nostalgic",
    "not",
    "specified",
    "noticed",
    "numb",
    "obeyed",
    "objective",
    "obligated",
    "obvious",
    "odd",
    "offended",
    "okay",
    "old",
    "open",
    "oppressed",
    "optimistic",
    "ornery",
    "control",
    "outraged",
    "overcome",
    "overjoyed",
    "overloaded",
    "overwhelmed",
    "owned",
    "painful",
    "pampered",
    "panicky",
    "passionate",
    "patient",
    "patronizing",
    "peaceful",
    "peeved",
    "persecuted",
    "pessimistic",
    "pestered",
    "petrified",
    "petty",
    "phony",
    "pious",
    "pissed",
    "off",
    "playful",
    "pleased",
    "poor",
    "possessive",
    "powerful",
    "powerless",
    "practical",
    "predatory",
    "pressured",
    "productive",
    "protected",
    "protective",
    "proud",
    "provoked",
    "prudish",
    "punished",
    "pushy",
    "puzzled",
    "questioned",
    "quiet",
    "quixotic",
    "quizzical",
    "rambunctious",
    "realistic",
    "reassured",
    "rebellious",
    "reborn",
    "receptive",
    "reckless",
    "recognized",
    "reconciled",
    "recumbent",
    "reflective",
    "refreshed",
    "regretful",
    "rejected",
    "rejuvenated",
    "relaxed",
    "released",
    "relieved",
    "reluctant",
    "remorse",
    "renewed",
    "replaced",
    "replenished",
    "repressed",
    "rescued",
    "resentful",
    "reserved",
    "resistant",
    "resourceful",
    "respected",
    "responsible",
    "restless",
    "restricted",
    "revengeful",
    "reverent",
    "revitalized",
    "ribald",
    "rich",
    "ridicule",
    "right",
    "rigid",
    "robbed",
    "romantic",
    "rotten",
    "rushed",
    "sabotaged",
    "sad",
    "safe",
    "sarcastic",
    "sardonic",
    "sassy",
    "satiated",
    "satiric",
    "satisfied",
    "scared",
    "scolded",
    "scorned",
    "secure",
    "seductive",
    "selfish",
    "self-centered",
    "self-conscious",
    "self-reliant",
    "sensitive",
    "sentimental",
    "serene",
    "serious",
    "sexy",
    "shamed",
    "sheepish",
    "shocked",
    "shunned",
    "shy",
    "sick",
    "silenced",
    "silly",
    "sincere",
    "sinful",
    "skeptical",
    "skillful",
    "slandered",
    "sluggish",
    "small",
    "smart",
    "solemn",
    "somber",
    "soothed",
    "sorry",
    "special",
    "spiteful",
    "splendid",
    "spunky",
    "squashed",
    "stifled",
    "stimulated",
    "stingy",
    "stressed",
    "stretched",
    "strong",
    "stumped",
    "stunned",
    "stupid",
    "submissive",
    "successful",
    "suffocated",
    "suicidal",
    "sullen",
    "sunk",
    "super",
    "superior",
    "supported",
    "sure",
    "surly",
    "surprised",
    "suspicious",
    "sympathetic",
    "tacky",
    "tactful",
    "talented",
    "talkative",
    "tame",
    "tarnished",
    "tasteful",
    "tearful",
    "teased",
    "tenacious",
    "tender",
    "tense",
    "tepid",
    "terrible",
    "terrific",
    "terrified",
    "terrifying",
    "tested",
    "testy",
    "thankful",
    "thoughtful",
    "threatened",
    "thrifty",
    "thrilled",
    "tired",
    "tormented",
    "torn",
    "tortured",
    "touched",
    "tough",
    "tragic",
    "tranquil",
    "treasured",
    "trembly",
    "tremendous",
    "tricked",
    "troubled",
    "trusted",
    "trustful",
    "ugly",
    "unaccepted",
    "unappreciated",
    "unbalanced",
    "unburdened",
    "uncanny",
    "unconcerned",
    "uneven",
    "unfit",
    "unfriendly",
    "united",
    "unjust",
    "unknown",
    "unneeded",
    "unreal",
    "unruly",
    "unwise",
    "up",
    "uplifted",
    "used",
    "vacant",
    "vague",
    "vain",
    "vengeful",
    "vexed",
    "vicious",
    "victimized",
    "victorious",
    "violated",
    "violent",
    "vivacious",
    "vivid",
    "void",
    "wacky",
    "warm",
    "warmhearted",
    "warned",
    "wary",
    "wasted",
    "weak",
    "wealthy",
    "weary",
    "weird",
    "welcoming",
    "whimsical",
    "whole",
    "wild",
    "wishful",
    "witty",
    "worried",
    "worse",
    "worthy",
    "wounded",
    "wrong",
    "yearning",
    "yellow",
    "yielding",
    "young",
    "youthful",
    "zany",
    "zealous"
]

MOODS = [
    "abandoned",
    "abused",
    "accepted",
    "accomplished",
    "accusatory",
    "accused",
    "admired",
    "adored",
    "adrift",
    "affectionate",
    "afraid",
    "aggravated",
    "aggressive",
    "agitated",
    "alarmed",
    "alert",
    "alienated",
    "alive",
    "alluring",
    "alone",
    "aloof",
    "amazed",
    "ambushed",
    "amused",
    "angry",
    "annoyed",
    "antagonistic",
    "anxious",
    "apathetic",
    "apologetic",
    "appalled",
    "appreciated",
    "appreciative",
    "apprehensive",
    "aroused",
    "ashamed",
    "astonished",
    "attacked",
    "attractive",
    "awake",
    "aware",
    "awe",
    "awed",
    "awestruck",
    "awkward",
    "bad",
    "baffled",
    "barren",
    "bashful",
    "beaten",
    "belittled",
    "benevolent",
    "berated",
    "betrayed",
    "bewildered",
    "bitchy",
    "bitter",
    "bittersweet",
    "blah",
    "blamed",
    "blank",
    "blissful",
    "blue",
    "bold",
    "bored",
    "bothered",
    "bouncy",
    "brave",
    "broken",
    "brooding",
    "bummed",
    "burdened",
    "burned",
    "callous",
    "calm",
    "capable",
    "carefree",
    "careless",
    "caring",
    "caustic",
    "cautious",
    "censored",
    "centered",
    "certain",
    "challenged",
    "charmed",
    "cheated",
    "cheerful",
    "cherished",
    "childish",
    "chipper",
    "choleric",
    "clean",
    "clear",
    "clever",
    "close",
    "closed",
    "clueless",
    "clumsy",
    "cold",
    "comfortable",
    "committed",
    "compassionate",
    "competent",
    "competitive",
    "complacent",
    "complete",
    "concerned",
    "condemned",
    "condescension",
    "confident",
    "confining",
    "confused",
    "considerate",
    "contemplative",
    "contempt",
    "contemptuous",
    "content",
    "controlled",
    "conventional",
    "convicted",
    "cornered",
    "courageous",
    "cowardly",
    "cranky",
    "crappy",
    "crazy",
    "critical",
    "cross",
    "crushed",
    "curious",
    "cynical",
    "daring",
    "dark",
    "dashed",
    "dazed",
    "dead",
    "deceived",
    "dedicated",
    "defeated",
    "defenseless",
    "defensive",
    "defiant",
    "degraded",
    "dejected",
    "delicate",
    "delighted",
    "demoralized",
    "dependent",
    "depressed",
    "deprived",
    "derisive",
    "deserted",
    "desired",
    "desolate",
    "despair",
    "desperate",
    "destroyed",
    "detached",
    "determined",
    "devastated",
    "devious",
    "devoted",
    "didactic",
    "different",
    "difficult",
    "dignified",
    "dirty",
    "disappointed",
    "disbelieving",
    "discarded",
    "disconnected",
    "discontent",
    "discontented",
    "discouraged",
    "disdainful",
    "disgraced",
    "disgusted",
    "disheartened",
    "dishonest",
    "disillusioned",
    "dismal",
    "dismayed",
    "disobedient",
    "disorganized",
    "disposable",
    "distant",
    "distracted",
    "distressed",
    "disturbed",
    "ditzy",
    "dorky",
    "doubtful",
    "down",
    "drained",
    "dreamy",
    "dreary",
    "dropped",
    "drunk",
    "dull",
    "dumb",
    "eager",
    "earnest",
    "ecstatic",
    "edgy",
    "effective",
    "elated",
    "embarassed",
    "embarrassed",
    "empathetic",
    "empowered",
    "empty",
    "enchanted",
    "encouraged",
    "energetic",
    "energized",
    "enlightened",
    "enraged",
    "enriched",
    "entertained",
    "enthralled",
    "enthusiastic",
    "envious",
    "erudite",
    "evasive",
    "evil",
    "exasperated",
    "excited",
    "excluded",
    "exhausted",
    "exhilarated",
    "expectant",
    "exploited",
    "exposed",
    "exuberant",
    "faithful",
    "fake",
    "fanciful",
    "fantastic",
    "fatalistic",
    "fatigued",
    "fearful",
    "fearless",
    "feisty",
    "fine",
    "flirty",
    "flustered",
    "foolish",
    "foreboding",
    "forgiven",
    "forgiving",
    "forgotten",
    "forthright",
    "fortunate",
    "framed",
    "frantic",
    "free",
    "friendly",
    "frightened",
    "frisky",
    "frustrated",
    "fulfilled",
    "full",
    "funny",
    "furious",
    "futile",
    "geeky",
    "generous",
    "gentle",
    "giddy",
    "giggly",
    "giving",
    "glad",
    "gloomy",
    "glorious",
    "good",
    "grateful",
    "great",
    "grieving",
    "groggy",
    "grouchy",
    "grumpy",
    "guarded",
    "guilty",
    "gullible",
    "handicapped",
    "happy",
    "harmonious",
    "hateful",
    "haughty",
    "haunted",
    "haunting",
    "healthy",
    "heard",
    "heartbroken",
    "heavy-hearted",
    "helpful",
    "helpless",
    "hesitant",
    "high",
    "honored",
    "hopeful",
    "hopeless",
    "horrible",
    "horrified",
    "hospitable",
    "hostile",
    "hot",
    "humble",
    "humiliated",
    "hungry",
    "hurt",
    "hyper",
    "hysterical",
    "idealistic",
    "idiotic",
    "idyllic",
    "ignorant",
    "ignored",
    "imaginative",
    "immune",
    "impatient",
    "impelled",
    "imperfect",
    "impertinent",
    "important",
    "impressed",
    "impulsive",
    "inadequate",
    "inattentive",
    "incensed",
    "inclusive",
    "incompetent",
    "incomplete",
    "incredulous",
    "indebted",
    "indecisive",
    "independent",
    "indescribable",
    "indifferent",
    "indignant",
    "industrious",
    "inept",
    "inferior",
    "inflated",
    "informed",
    "infuriated",
    "inhibited",
    "innocent",
    "innovative",
    "inquisitive",
    "insane",
    "insecure",
    "insensitive",
    "insidious",
    "insignificant",
    "insulted",
    "intense",
    "interested",
    "interrogated",
    "interrupted",
    "intimate",
    "intimidated",
    "intrigued",
    "invigorated",
    "invisible",
    "involved",
    "irate",
    "irked",
    "irrational",
    "irresponsible",
    "irritated",
    "isolated",
    "jaded",
    "jealous",
    "jinxed",
    "jolly",
    "jovial",
    "joyful",
    "joyous",
    "jubilant",
    "judged",
    "judgmental",
    "jumpy",
    "just",
    "justified",
    "kidded",
    "kind",
    "knowledgeable",
    "late",
    "lazy",
    "leery",
    "left",
    "let",
    "lethargic",
    "liable",
    "liberated",
    "liberating",
    "lifeless",
    "light-hearted",
    "liked",
    "listened",
    "listless",
    "logical",
    "lonely",
    "loose",
    "lost",
    "lousy",
    "lovable",
    "loved",
    "loving",
    "lucky",
    "lyrical",
    "mad",
    "malicious",
    "manipulated",
    "matter",
    "fact",
    "mean",
    "meditative",
    "melancholic",
    "melancholy",
    "mellow",
    "merciless",
    "merry",
    "mischievous",
    "miserable",
    "misinterpreted",
    "mistreated",
    "misunderstood",
    "mixed",
    "mocked",
    "mocking",
    "modest",
    "molested",
    "moody",
    "morose",
    "motivated",
    "mournful",
    "moved",
    "mystified",
    "naive",
    "nasty",
    "naughty",
    "nauseated",
    "needed",
    "needy",
    "negative",
    "neglected",
    "nerdy",
    "nervous",
    "neurotic",
    "nightmarish",
    "nonchalant",
    "nostalgic",
    "not",
    "specified",
    "noticed",
    "numb",
    "obeyed",
    "objective",
    "obligated",
    "obvious",
    "odd",
    "offended",
    "okay",
    "old",
    "open",
    "oppressed",
    "optimistic",
    "ornery",
    "control",
    "outraged",
    "overcome",
    "overjoyed",
    "overloaded",
    "overwhelmed",
    "overworked",
    "owned",
    "painful",
    "pampered",
    "panicky",
    "paralyzed",
    "passionate",
    "passive",
    "patient",
    "patronizing",
    "peaceful",
    "peeved",
    "pensive",
    "perky",
    "perplexed",
    "persecuted",
    "pessimistic",
    "pestered",
    "petrified",
    "petty",
    "phony",
    "pious",
    "pissed",
    "off",
    "playful",
    "pleased",
    "poor",
    "positive",
    "possessive",
    "powerful",
    "powerless",
    "practical",
    "predatory",
    "pressured",
    "private",
    "productive",
    "protected",
    "protective",
    "proud",
    "provoked",
    "prudish",
    "punished",
    "pushy",
    "puzzled",
    "questioned",
    "quiet",
    "quixotic",
    "quizzical",
    "rambunctious",
    "realistic",
    "reassured",
    "rebellious",
    "reborn",
    "receptive",
    "reckless",
    "recognized",
    "reconciled",
    "recumbent",
    "reflective",
    "refreshed",
    "regretful",
    "rejected",
    "rejuvenated",
    "relaxed",
    "released",
    "relieved",
    "reluctant",
    "reminiscent",
    "remorse",
    "renewed",
    "replaced",
    "replenished",
    "repressed",
    "rescued",
    "resentful",
    "reserved",
    "resistant",
    "resourceful",
    "respected",
    "responsible",
    "restless",
    "restricted",
    "revengeful",
    "reverent",
    "revitalized",
    "ribald",
    "rich",
    "ridicule",
    "ridiculous",
    "right",
    "rigid",
    "robbed",
    "romantic",
    "rotten",
    "rushed",
    "sabotaged",
    "sad",
    "safe",
    "sarcastic",
    "sardonic",
    "sassy",
    "satiated",
    "satiric",
    "satisfied",
    "saved",
    "scared",
    "scolded",
    "scorned",
    "secure",
    "seductive",
    "selfish",
    "self-assured",
    "self-centered",
    "self-confident",
    "self-conscious",
    "self-destructive",
    "self-reliant",
    "sensitive",
    "sentimental",
    "serene",
    "serious",
    "sexy",
    "shaken",
    "shamed",
    "sheepish",
    "shocked",
    "shunned",
    "shy",
    "sick",
    "silenced",
    "silly",
    "sincere",
    "sinful",
    "skeptical",
    "skillful",
    "slandered",
    "sleepy",
    "sluggish",
    "small",
    "smart",
    "smothered",
    "solemn",
    "somber",
    "soothed",
    "sorry",
    "special",
    "spiteful",
    "splendid",
    "spunky",
    "squashed",
    "stifled",
    "stimulated",
    "stingy",
    "strained",
    "stressed",
    "stretched",
    "strong",
    "stubborn",
    "stumped",
    "stunned",
    "stupid",
    "submissive",
    "successful",
    "suffocated",
    "suicidal",
    "sullen",
    "sunk",
    "super",
    "superior",
    "supported",
    "sure",
    "surly",
    "surprised",
    "suspenseful",
    "suspicious",
    "sympathetic",
    "tacky",
    "tactful",
    "talented",
    "talkative",
    "tame",
    "tarnished",
    "tasteful",
    "tearful",
    "teased",
    "tenacious",
    "tender",
    "tense",
    "tepid",
    "terrible",
    "terrific",
    "terrified",
    "terrifying",
    "tested",
    "testy",
    "thankful",
    "thoughtful",
    "threatened",
    "threatening",
    "thrifty",
    "thrilled",
    "tired",
    "tormented",
    "torn",
    "tortured",
    "touched",
    "tough",
    "tragic",
    "tranquil",
    "transformed",
    "trapped",
    "treasured",
    "trembly",
    "tremendous",
    "tricked",
    "troubled",
    "trusted",
    "trustful",
    "ugly",
    "unaccepted",
    "unappreciated",
    "unbalanced",
    "unburdened",
    "uncanny",
    "uncomfortable",
    "unconcerned",
    "uneven",
    "unfit",
    "unfriendly",
    "united",
    "unjust",
    "unknown",
    "unneeded",
    "unpleasant",
    "unreal",
    "unruly",
    "unwise",
    "up",
    "uplifted",
    "used",
    "useless",
    "vacant",
    "vague",
    "vain",
    "valid",
    "valued",
    "vengeful",
    "vexed",
    "vicious",
    "victimized",
    "victorious",
    "violated",
    "violent",
    "vivacious",
    "vivid",
    "void",
    "wacky",
    "warlike",
    "warm",
    "warmhearted",
    "warned",
    "wary",
    "wasted",
    "weak",
    "wealthy",
    "weary",
    "weird",
    "welcoming",
    "whimsical",
    "whole",
    "wild",
    "willful",
    "wishful",
    "witty",
    "worldly",
    "worried",
    "worse",
    "worthy",
    "wounded",
    "wrong",
    "yearning",
    "yellow",
    "yielding",
    "young",
    "youthful",
    "zany",
    "zealous"
]



VERBS = [
  "accept",
  "accepted",
  "add",
  "added",
  "admire",
  "admired",
  "admit",
  "admitted",
  "advise",
  "advised",
  "afford",
  "afforded",
  "agree",
  "agreed",
  "alert",
  "alerted",
  "allow",
  "allowed",
  "amuse",
  "amused",
  "analyse",
  "analysed",
  "announce",
  "announced",
  "annoy",
  "annoyed",
  "answer",
  "answered",
  "apologise",
  "apologised",
  "appear",
  "appeared",
  "applaud",
  "applauded",
  "appreciate",
  "appreciated",
  "approve",
  "approved",
  "argue",
  "argued",
  "arrange",
  "arranged",
  "arrest",
  "arrested",
  "arrive",
  "arrived",
  "ask",
  "asked",
  "attach",
  "attached",
  "attack",
  "attacked",
  "attempt",
  "attempted",
  "attend",
  "attended",
  "attract",
  "attracted",
  "avoid",
  "avoided",
  "back",
  "backed",
  "bake",
  "baked",
  "balance",
  "balanced",
  "ban",
  "bang",
  "banged",
  "banned",
  "bare",
  "bared",
  "bat",
  "bathe",
  "bathed",
  "batted",
  "battle",
  "battled",
  "beam",
  "beamed",
  "beg",
  "begged",
  "behave",
  "behaved",
  "belong",
  "belonged",
  "bleach",
  "bleached",
  "bless",
  "blessed",
  "blind",
  "blinded",
  "blink",
  "blinked",
  "blot",
  "blotted",
  "blush",
  "blushed",
  "boast",
  "boasted",
  "boil",
  "boiled",
  "bolt",
  "bolted",
  "bomb",
  "bombed",
  "book",
  "booked",
  "bore",
  "bored",
  "borrow",
  "borrowed",
  "bounce",
  "bounced",
  "bow",
  "bowed",
  "box",
  "boxed",
  "brake",
  "braked",
  "branch",
  "branched",
  "breathe",
  "breathed",
  "bruise",
  "bruised",
  "brush",
  "brushed",
  "bubble",
  "bubbled",
  "bump",
  "bumped",
  "buried",
  "burn",
  "burned",
  "bury",
  "buzz",
  "buzzed",
  "calculate",
  "calculated",
  "call",
  "called",
  "camp",
  "camped",
  "care",
  "cared",
  "carried",
  "carry",
  "carve",
  "carved",
  "cause",
  "caused",
  "challenge",
  "challenged",
  "change",
  "changed",
  "charge",
  "charged",
  "chase",
  "chased",
  "cheat",
  "cheated",
  "check",
  "checked",
  "cheer",
  "cheered",
  "chew",
  "chewed",
  "choke",
  "choked",
  "chop",
  "chopped",
  "claim",
  "claimed",
  "clap",
  "clapped",
  "clean",
  "cleaned",
  "clear",
  "cleared",
  "clip",
  "clipped",
  "close",
  "closed",
  "coach",
  "coached",
  "coil",
  "coiled",
  "collect",
  "collected",
  "colour",
  "coloured",
  "comb",
  "combed",
  "command",
  "commanded",
  "communicate",
  "communicated",
  "compare",
  "compared",
  "compete",
  "competed",
  "complain",
  "complained",
  "complete",
  "completed",
  "concentrate",
  "concentrated",
  "concern",
  "concerned",
  "confess",
  "confessed",
  "confuse",
  "confused",
  "connect",
  "connected",
  "consider",
  "considered",
  "consist",
  "consisted",
  "contain",
  "contained",
  "continue",
  "continued",
  "copied",
  "copy",
  "correct",
  "corrected",
  "cough",
  "coughed",
  "count",
  "counted",
  "cover",
  "covered",
  "crack",
  "cracked",
  "crash",
  "crashed",
  "crawl",
  "crawled",
  "cried",
  "cross",
  "crossed",
  "crush",
  "crushed",
  "cry",
  "cure",
  "cured",
  "curl",
  "curled",
  "curve",
  "curved",
  "cycle",
  "cycled",
  "dam",
  "damage",
  "damaged",
  "dammed",
  "dance",
  "danced",
  "dare",
  "dared",
  "decay",
  "decayed",
  "deceive",
  "deceived",
  "decide",
  "decided",
  "decorate",
  "decorated",
  "delay",
  "delayed",
  "delight",
  "delighted",
  "deliver",
  "delivered",
  "depend",
  "depended",
  "describe",
  "described",
  "desert",
  "deserted",
  "deserve",
  "deserved",
  "destroy",
  "destroyed",
  "detect",
  "detected",
  "develop",
  "developed",
  "disagree",
  "disagreed",
  "disappear",
  "disappeared",
  "disapprove",
  "disapproved",
  "disarm",
  "disarmed",
  "discover",
  "discovered",
  "dislike",
  "disliked",
  "divide",
  "divided",
  "double",
  "doubled",
  "doubt",
  "doubted",
  "drag",
  "dragged",
  "drain",
  "drained",
  "dream",
  "dreamed",
  "dress",
  "dressed",
  "dried",
  "drip",
  "dripped",
  "drop",
  "dropped",
  "drown",
  "drowned",
  "drum",
  "drummed",
  "dry",
  "dust",
  "dusted",
  "earn",
  "earned",
  "educate",
  "educated",
  "embarrass",
  "embarrassed",
  "employ",
  "employed",
  "emptied",
  "empty",
  "encourage",
  "encouraged",
  "end",
  "ended",
  "enjoy",
  "enjoyed",
  "enter",
  "entered",
  "entertain",
  "entertained",
  "escape",
  "escaped",
  "examine",
  "examined",
  "excite",
  "excited",
  "excuse",
  "excused",
  "exercise",
  "exercised",
  "exist",
  "existed",
  "expand",
  "expand",
  "expect",
  "expected",
  "explain",
  "explained",
  "explode",
  "exploded",
  "extend",
  "extended",
  "face",
  "faced",
  "fade",
  "faded",
  "fail",
  "failed",
  "fancied",
  "fancy",
  "fasten",
  "fastened",
  "fax",
  "faxed",
  "fear",
  "feared",
  "fence",
  "fenced",
  "fetch",
  "fetched",
  "file",
  "filed",
  "fill",
  "filled",
  "film",
  "filmed",
  "fire",
  "fired",
  "fit",
  "fitted",
  "fix",
  "fixed",
  "flap",
  "flapped",
  "flash",
  "flashed",
  "float",
  "floated",
  "flood",
  "flooded",
  "flow",
  "fly",
  "flowed",
  "flower",
  "flowered",
  "fold",
  "folded",
  "follow",
  "followed",
  "fool",
  "fooled",
  "force",
  "forced",
  "form",
  "formed",
  "found",
  "founded",
  "frame",
  "framed",
  "fried",
  "frighten",
  "frightened",
  "fry",
  "gather",
  "gathered",
  "gaze",
  "gazed",
  "glow",
  "glowed",
  "glue",
  "glued",
  "grab",
  "grabbed",
  "grate",
  "grated",
  "grease",
  "greased",
  "greet",
  "greeted",
  "grin",
  "grinned",
  "grip",
  "gripped",
  "groan",
  "groaned",
  "guarantee",
  "guaranteed",
  "guard",
  "guarded",
  "guess",
  "guessed",
  "guide",
  "guided",
  "hammer",
  "hammered",
  "hand",
  "handed",
  "handle",
  "handled",
  "hang",
  "happen",
  "happened",
  "harass",
  "harassed",
  "harm",
  "harmed",
  "hate",
  "hated",
  "haunt",
  "haunted",
  "head",
  "headed",
  "heal",
  "healed",
  "heap",
  "heaped",
  "heat",
  "heated",
  "help",
  "helped",
  "hook",
  "hooked",
  "hop",
  "hope",
  "hoped",
  "hopped",
  "hover",
  "hovered",
  "hug",
  "hugged",
  "hum",
  "hummed",
  "hung",
  "hunt",
  "hunted",
  "hurried",
  "hurry",
  "identified",
  "identify",
  "ignore",
  "ignored",
  "imagine",
  "imagined",
  "impress",
  "impressed",
  "improve",
  "improved",
  "include",
  "included",
  "increase",
  "increased",
  "influence",
  "influenced",
  "inform",
  "informed",
  "inject",
  "injected",
  "injure",
  "injured",
  "instruct",
  "instructed",
  "intend",
  "intended",
  "interest",
  "interested",
  "interfere",
  "interfered",
  "interrupt",
  "interrupted",
  "introduce",
  "introduced",
  "invent",
  "invented",
  "invite",
  "invited",
  "irritate",
  "irritated",
  "itch",
  "itched",
  "jail",
  "jailed",
  "jam",
  "jammed",
  "jog",
  "jogged",
  "join",
  "joined",
  "joke",
  "joked",
  "judge",
  "judged",
  "juggle",
  "juggled",
  "jump",
  "jumped",
  "kick",
  "kicked",
  "kill",
  "killed",
  "kiss",
  "kissed",
  "kneel",
  "knelt",
  "knit",
  "knitted",
  "knock",
  "knocked",
  "knot",
  "knotted",
  "label",
  "labelled",
  "land",
  "landed",
  "last",
  "lasted",
  "laugh",
  "laughed",
  "launch",
  "launched",
  "learn",
  "learned",
  "level",
  "levelled",
  "license",
  "licensed",
  "lick",
  "licked",
  "lie",
  "lied",
  "lighten",
  "lightened",
  "like",
  "liked",
  "list",
  "listed",
  "listen",
  "listened",
  "live",
  "lived",
  "load",
  "loaded",
  "lock",
  "locked",
  "long",
  "longed",
  "look",
  "look",
  "love",
  "loved",
  "man",
  "manage",
  "managed",
  "manned",
  "march",
  "marched",
  "mark",
  "marked",
  "married",
  "marry",
  "match",
  "matched",
  "mate",
  "mated",
  "matter",
  "mattered",
  "measure",
  "measured",
  "meddle",
  "meddled",
  "melt",
  "melted",
  "memorise",
  "memorised",
  "mend",
  "mended",
  "mess",
  "messed",
  "milk",
  "milked",
  "mine",
  "mined",
  "miss",
  "missed",
  "mix",
  "mixed",
  "moan",
  "moaned",
  "moor",
  "moored",
  "mourn",
  "mourned",
  "move",
  "moved",
  "muddle",
  "muddled",
  "mug",
  "mugged",
  "multiplied",
  "multiply",
  "murder",
  "murdered",
  "nail",
  "nailed",
  "name",
  "named",
  "need",
  "needed",
  "nest",
  "nested",
  "nod",
  "nodded",
  "note",
  "noted",
  "notice",
  "noticed",
  "number",
  "numbered",
  "obey",
  "obeyed",
  "object",
  "objected",
  "observe",
  "observed",
  "obtain",
  "obtained",
  "occur",
  "occurred",
  "offend",
  "offended",
  "offer",
  "offered",
  "open",
  "opened",
  "order",
  "ordered",
  "overflow",
  "overflowed",
  "owe",
  "owed",
  "own",
  "owned",
  "pack",
  "packed",
  "paddle",
  "paddled",
  "paint",
  "painted",
  "park",
  "parked",
  "part",
  "parted",
  "pass",
  "passed",
  "paste",
  "pasted",
  "pat",
  "patted",
  "pause",
  "paused",
  "peck",
  "pecked",
  "pedal",
  "pedalled",
  "peel",
  "peeled",
  "peep",
  "peeped",
  "perform",
  "performed",
  "permit",
  "permitted",
  "phone",
  "phoned",
  "pick",
  "picked",
  "pinch",
  "pinched",
  "pine",
  "pined",
  "place",
  "placed",
  "plan",
  "planned",
  "plant",
  "planted",
  "play",
  "played",
  "please",
  "pleased",
  "plug",
  "plugged",
  "point",
  "pointed",
  "poke",
  "poked",
  "polish",
  "polished",
  "pop",
  "popped",
  "possess",
  "possessed",
  "post",
  "posted",
  "pour",
  "poured",
  "practise",
  "practised",
  "pray",
  "prayed",
  "preach",
  "preached",
  "precede",
  "preceded",
  "prefer",
  "preferred",
  "prepare",
  "prepared",
  "present",
  "presented",
  "preserve",
  "preserved",
  "press",
  "pressed",
  "pretend",
  "pretended",
  "prevent",
  "prevented",
  "prick",
  "pricked",
  "print",
  "printed",
  "produce",
  "produced",
  "program",
  "programmed",
  "promise",
  "promised",
  "protect",
  "protected",
  "provide",
  "provided",
  "pull",
  "pulled",
  "pump",
  "pumped",
  "punch",
  "punched",
  "puncture",
  "punctured",
  "punish",
  "punished",
  "push",
  "pushed",
  "question",
  "questioned",
  "questioned",
  "queue",
  "race",
  "raced",
  "radiate",
  "radiated",
  "rain",
  "rained",
  "raise",
  "raised",
  "reach",
  "reached",
  "realise",
  "realised",
  "receive",
  "received",
  "recognise",
  "recognised",
  "record",
  "recorded",
  "reduce",
  "reduced",
  "reflect",
  "reflected",
  "refuse",
  "refused",
  "regret",
  "regretted",
  "reign",
  "reigned",
  "reject",
  "rejected",
  "rejoice",
  "rejoiced",
  "relax",
  "relaxed",
  "release",
  "released",
  "relied",
  "rely",
  "remain",
  "remained",
  "remember",
  "remembered",
  "remind",
  "reminded",
  "remove",
  "removed",
  "repair",
  "repaired",
  "repeat",
  "repeated",
  "replace",
  "replaced",
  "replied",
  "reply",
  "report",
  "reported",
  "reproduce",
  "reproduced",
  "request",
  "requested",
  "rescue",
  "rescued",
  "retire",
  "retired",
  "return",
  "returned",
  "rhyme",
  "rhyme",
  "rinse",
  "rinsed",
  "risk",
  "risked",
  "rob",
  "robbed",
  "rock",
  "rocked",
  "roll",
  "rolled",
  "rot",
  "rotted",
  "rub",
  "rubbed",
  "ruin",
  "ruined",
  "rule",
  "ruled",
  "rush",
  "rushed",
  "run",
  "sack",
  "sacked",
  "sail",
  "sailed",
  "satisfied",
  "satisfy",
  "save",
  "saved",
  "saw",
  "sawed",
  "scare",
  "scared",
  "scatter",
  "scattered",
  "scold",
  "scolded",
  "scorch",
  "scorched",
  "scrape",
  "scraped",
  "scratch",
  "scratched",
  "scream",
  "screamed",
  "screw",
  "screwed",
  "scribble",
  "scribbled",
  "scrub",
  "scrubbed",
  "seal",
  "sealed",
  "search",
  "searched",
  "separate",
  "separate",
  "serve",
  "served",
  "settle",
  "settled",
  "shade",
  "shaded",
  "share",
  "shared",
  "shave",
  "shaved",
  "shelter",
  "sheltered",
  "shiver",
  "shivered",
  "shock",
  "shocked",
  "shop",
  "shopped",
  "shrug",
  "shrugged",
  "sigh",
  "sighed",
  "sign",
  "signal",
  "signalled",
  "signed",
  "sin",
  "sinned",
  "sip",
  "sipped",
  "ski",
  "skied",
  "skip",
  "skipped",
  "slap",
  "slapped",
  "slip",
  "slipped",
  "slow",
  "slowed",
  "smash",
  "smashed",
  "smell",
  "smelled",
  "smile",
  "smiled",
  "smoke",
  "smoked",
  "snatch",
  "snatched",
  "sneeze",
  "sneezed",
  "sniff",
  "sniffed",
  "snore",
  "snored",
  "snow",
  "snowed",
  "soak",
  "soaked",
  "soothe",
  "soothed",
  "sound",
  "sounded",
  "spare",
  "spared",
  "spark",
  "sparked",
  "sparkle",
  "sparkled",
  "spell",
  "spelled",
  "spill",
  "spilled",
  "spoil",
  "spoiled",
  "spot",
  "spotted",
  "spray",
  "sprayed",
  "sprout",
  "sprouted",
  "squash",
  "squashed",
  "squeak",
  "squeaked",
  "squeal",
  "squealed",
  "squeeze",
  "squeezed",
  "stain",
  "stained",
  "stamp",
  "stamped",
  "stare",
  "stared",
  "start",
  "started",
  "stay",
  "stayed",
  "steer",
  "steered",
  "step",
  "stepped",
  "stir",
  "stirred",
  "stitch",
  "stitched",
  "stop",
  "stopped",
  "store",
  "stored",
  "strap",
  "strapped",
  "strengthen",
  "strengthened",
  "stretch",
  "stretched",
  "strip",
  "stripped",
  "stroke",
  "stroked",
  "stuff",
  "stuffed",
  "subtract",
  "subtracted",
  "succeed",
  "succeeded",
  "suck",
  "sucked",
  "suffer",
  "suffered",
  "suggest",
  "suggested",
  "suit",
  "suited",
  "supplied",
  "supply",
  "support",
  "supported",
  "suppose",
  "supposed",
  "surprise",
  "surprised",
  "surround",
  "surrounded",
  "suspect",
  "suspected",
  "suspend",
  "suspended",
  "switch",
  "switched",
  "talk",
  "talked",
  "tame",
  "tamed",
  "tap",
  "tapped",
  "taste",
  "tasted",
  "tease",
  "teased",
  "telephone",
  "telephoned",
  "tempt",
  "tempted",
  "terrified",
  "terrify",
  "test",
  "tested",
  "thank",
  "thanked",
  "thaw",
  "thawed",
  "tick",
  "ticked",
  "tickle",
  "tickled",
  "tie",
  "tied",
  "time",
  "timed",
  "tip",
  "tipped",
  "tire",
  "tired",
  "touch",
  "touched",
  "tour",
  "toured",
  "tow",
  "towed",
  "trace",
  "traced",
  "trade",
  "traded",
  "train",
  "trained",
  "transport",
  "transported",
  "trap",
  "trapped",
  "travel",
  "travelled",
  "treat",
  "treated",
  "tremble",
  "trembled",
  "trick",
  "tricked",
  "tried",
  "trip",
  "tripped",
  "trot",
  "trotted",
  "trouble",
  "troubled",
  "trust",
  "trusted",
  "try",
  "tug",
  "tugged",
  "tumble",
  "tumbled",
  "turn",
  "turned",
  "twist",
  "twisted",
  "type",
  "typed",
  "undress",
  "undressed",
  "unfasten",
  "unfastened",
  "unite",
  "united",
  "unlock",
  "unlocked",
  "unpack",
  "unpacked",
  "untidied",
  "untidy",
  "use",
  "used",
  "vanish",
  "vanished",
  "visit",
  "visited",
  "wail",
  "wailed",
  "wait",
  "waited",
  "walk",
  "walked",
  "wander",
  "wandered",
  "want",
  "wanted",
  "warm",
  "warmed",
  "warn",
  "warned",
  "wash",
  "washed",
  "waste",
  "wasted",
  "watch",
  "watched",
  "water",
  "watered",
  "wave",
  "waved",
  "weigh",
  "weighed",
  "welcome",
  "welcomed",
  "whine",
  "whined",
  "whip",
  "whipped",
  "whirl",
  "whirled",
  "whisper",
  "whispered",
  "whistle",
  "whistled",
  "wink",
  "winked",
  "wipe",
  "wiped",
  "wish",
  "wished",
  "wobble",
  "wobbled",
  "wonder",
  "wondered",
  "work",
  "worked",
  "worried",
  "worry",
  "wrap",
  "wrapped",
  "wreck",
  "wrecked",
  "wrestle",
  "wrestled",
  "wriggle",
  "wriggled",
  "yawn",
  "yawned",
  "yell",
  "yelled",
  "zip",
  "zipped",
  "zoom",
  "zoomed"
]



NOUNS = [
  "outpost",
  "plaza",
  "affinity",
  "residency",
  "spaghetti",
  "crow",
  "reinstatement",
  "forefront",
  "boldness",
  "repository",
  "syndrome",
  "vampire",
  "moose",
  "devolution",
  "announcement",
  "mutation",
  "likeness",
  "zebra",
  "confidant",
  "coaster",
  "rhododendron",
  "crossroads",
  "deflation",
  "oryx",
  "rubbing",
  "ballet",
  "lordship",
  "nutrition",
  "framework",
  "conspiracy",
  "scissors",
  "gnu",
  "gallery",
  "countryman",
  "longevity",
  "dexterity",
  "publicist",
  "sage",
  "mainframe",
  "condominium",
  "assembly",
  "drumming",
  "building",
  "piles",
  "obscurity",
  "vogue",
  "vegetation",
  "allotment",
  "carrier",
  "glucose",
  "nightmare",
  "delirium",
  "nervousness",
  "dialect",
  "observer",
  "consist",
  "restaurant",
  "beginner",
  "stimulus",
  "friendliness",
  "defection",
  "irrigation",
  "parrot",
  "monarchy",
  "violation",
  "hello",
  "embodiment",
  "dioxide",
  "lighting",
  "instruction",
  "horseman",
  "bluebell",
  "abstinence",
  "machinery",
  "emancipation",
  "overseer",
  "diagnosis",
  "ducking",
  "barrymore",
  "cartridge",
  "watchdog",
  "avarice",
  "association",
  "foyer",
  "patchwork",
  "poultry",
  "receptor",
  "bureaucracy",
  "snack",
  "fraud",
  "trilogy",
  "college",
  "firing",
  "cyclist",
  "iniquity",
  "mathematician",
  "intruder",
  "roadblock",
  "birthplace",
  "souvenir",
  "mythology",
  "counselor",
  "tendon",
  "ape",
  "distributor",
  "bullion",
  "rector",
  "drafting",
  "discovery",
  "metre",
  "interval",
  "badger",
  "rationality",
  "gallantry",
  "eyewitness",
  "cabbage",
  "intersection",
  "adultery",
  "demeanor",
  "intercession",
  "reader",
  "futility",
  "lineup",
  "shaving",
  "porpoise",
  "consultancy",
  "custard",
  "canary",
  "hedgehog",
  "scholarship",
  "slugger",
  "lion",
  "expediency",
  "cougar",
  "bonus",
  "success",
  "propensity",
  "terrier",
  "accounting",
  "molasses",
  "frigate",
  "reindeer",
  "novella",
  "turtle",
  "ratification",
  "regularity",
  "toad",
  "bomber",
  "transmitter",
  "tourist",
  "lynx",
  "terry",
  "dugout",
  "trout",
  "helplessness",
  "tourney",
  "adherence",
  "deer",
  "redistribution",
  "edelweiss",
  "artisan",
  "weariness",
  "actress",
  "outage",
  "persona",
  "chrysantemum",
  "unhappiness",
  "advert",
  "constable",
  "validity",
  "ambulance",
  "aesthetics",
  "campaign",
  "anemone",
  "actuality",
  "processor",
  "anemia",
  "emperor",
  "siding",
  "creator",
  "squid",
  "influx",
  "dishonesty",
  "maple",
  "despotism",
  "disarmament",
  "scouring",
  "cheerleader",
  "narration",
  "elements",
  "hyacinth",
  "hammock",
  "reaction",
  "bicycle",
  "crossover",
  "originality",
  "ocelot",
  "jenny",
  "allergy",
  "spectacle",
  "asthma",
  "comrade",
  "covering",
  "mouthful",
  "shopping",
  "feces",
  "error",
  "cyclone",
  "enlightenment",
  "hardship",
  "tendency",
  "goat",
  "seal",
  "bending",
  "cursor",
  "platypus",
  "monkey",
  "cat",
  "blossom",
  "greens",
  "redundancy",
  "dentist",
  "easter",
  "technology",
  "manifesto",
  "elk",
  "nourishment",
  "waitress",
  "ammonia",
  "tractor",
  "scrimmage",
  "mayer",
  "instructor",
  "conduit",
  "volcano",
  "underwear",
  "extinction",
  "ardor",
  "seizure",
  "sperm",
  "theater",
  "electricity",
  "llama",
  "plateau",
  "encouragement",
  "contractor",
  "correlation",
  "vindication",
  "coconut",
  "sheep",
  "absurdity",
  "frequency",
  "nexus",
  "exclamation",
  "aster",
  "recognition",
  "mongoose",
  "reformer",
  "sewing",
  "anthropology",
  "azalea",
  "heather",
  "pig",
  "hostility",
  "mango",
  "auspices",
  "handling",
  "environment",
  "battling",
  "madness",
  "accomplice",
  "lineage",
  "progression",
  "laurels",
  "sinking",
  "hibiscus",
  "feedback",
  "fundraiser",
  "digress",
  "koala",
  "saloon",
  "happiness",
  "weasel",
  "rendition",
  "snake",
  "bear",
  "sufferer",
  "captaincy",
  "gopher",
  "involvement",
  "potassium",
  "inactivity",
  "outing",
  "gorilla",
  "primrose",
  "dominion",
  "cumin",
  "investment",
  "posting",
  "armour",
  "caught",
  "leasing",
  "oracle",
  "header",
  "evacuation",
  "booty",
  "hamburger",
  "girlfriend",
  "hands",
  "iceberg",
  "melodrama",
  "schism",
  "opossum",
  "wildcat",
  "mechanics",
  "subcommittee",
  "earnestness",
  "housing",
  "bat",
  "storyteller",
  "peter",
  "begun",
  "airtime",
  "thunderstorm",
  "recipe",
  "horse",
  "lowry",
  "lodging",
  "thriller",
  "hog",
  "invasion",
  "hyena",
  "loathing",
  "victory",
  "advertising",
  "beaver",
  "seating",
  "acreage",
  "formality",
  "dedication",
  "ferocity",
  "misconception",
  "subsidy",
  "ascent",
  "pragmatism",
  "discord",
  "fluke",
  "coyote",
  "phrasing",
  "humility",
  "retirement",
  "tulip",
  "wolf",
  "boardroom",
  "locality",
  "mink",
  "oxygen",
  "banjo",
  "immunity",
  "hurricane",
  "interact",
  "thoroughfare",
  "setup",
  "redemption",
  "dossier",
  "gazelle",
  "detention",
  "suspension",
  "woodward",
  "chivalry",
  "formation",
  "proximity",
  "chipmunk",
  "variation",
  "broth",
  "physique",
  "bondage",
  "mahogany",
  "giraffe",
  "clearance",
  "doorway",
  "espionage",
  "mouse",
  "denomination",
  "envoy",
  "bergamot",
  "martin",
  "interpretation",
  "intermission",
  "pneumonia",
  "scenario",
  "enthusiasm",
  "legislation",
  "sorcery",
  "advertisement",
  "pharaoh",
  "artistry",
  "provider",
  "demonstration",
  "docking",
  "system",
  "dog",
  "attraction",
  "closeness",
  "allegiance",
  "vocalist",
  "logic",
  "publicity",
  "alligator",
  "buyout",
  "cutter",
  "words",
  "contentment",
  "completeness",
  "dealing",
  "lookout",
  "snail",
  "abbey",
  "pottery",
  "pasta",
  "syntax",
  "domination",
  "councilman",
  "tycoon",
  "climber",
  "otter",
  "blather",
  "reviewer",
  "breaker",
  "habitation",
  "buttercup",
  "stylus",
  "sweater",
  "phosphorus",
  "retention",
  "means",
  "toxicity",
  "supposition",
  "allies",
  "indecency",
  "mule",
  "rat",
  "mirth",
  "battery",
  "confiscation",
  "momentum",
  "peony",
  "proceeding",
  "annoyance",
  "baboon",
  "orientation",
  "barrister",
  "snark",
  "disability",
  "baron",
  "liberation",
  "degeneration",
  "allegory",
  "knocking",
  "specs",
  "dynamics",
  "indicator",
  "robber",
  "storey",
  "fox",
  "circus",
  "homeland",
  "boomer",
  "clutches",
  "repertoire",
  "privacy",
  "bird",
  "accuracy",
  "specimen",
  "prisoner",
  "rebirth",
  "meantime",
  "biography",
  "arrow",
  "chameleon",
  "pretense",
  "width",
  "resentment",
  "abundance",
  "depression",
  "marigold",
  "hacker",
  "china",
  "mover",
  "literature",
  "nationality",
  "schoolboy",
  "leopard",
  "carcass",
  "obscenity",
  "allocation",
  "layout",
  "kangaroo",
  "kingdom",
  "repayment",
  "vaccination",
  "aviation",
  "swimmer",
  "cropping",
  "seeder",
  "rosemary",
  "warthog",
  "reassurance",
  "threshold",
  "brewer",
  "suburb",
  "poker",
  "examination",
  "diver",
  "prophecy",
  "accommodation",
  "homer",
  "computing",
  "intolerance",
  "misunderstanding",
  "simulation",
  "altercation",
  "warmth",
  "anatomy",
  "standpoint",
  "outcome",
  "protein",
  "applause",
  "cornerstone",
  "eater",
  "whereabouts",
  "annuity",
  "advice",
  "woodchuck",
  "grouping",
  "refinery",
  "camel",
  "whiteness",
  "conflict",
  "republic",
  "runoff",
  "balls",
  "colleague",
  "equator",
  "buffalo",
  "eagerness",
  "liner",
  "damsel",
  "outfield",
  "maintenance",
  "resurgence",
  "squirrel",
  "drunkenness",
  "nobility",
  "amaranth",
  "pueblo",
  "mustang",
  "illustrator",
  "vanguard",
  "imprisonment",
  "outdoors",
  "sending",
  "stanza",
  "taker",
  "seduction",
  "reins",
  "drank",
  "backlash",
  "tuning",
  "encampment",
  "majority",
  "inaction",
  "ox",
  "corpus",
  "bookmark",
  "civilisation",
  "accreditation",
  "laborer",
  "function",
  "parson",
  "university",
  "jaguar",
  "medics",
  "parliament",
  "puberty",
  "functionality",
  "culprit",
  "ranger",
  "zinnia",
  "specification",
  "orchid",
  "broccoli",
  "mentality",
  "youngster",
  "rancher",
  "vulnerability",
  "ewe",
  "impala",
  "wombat",
  "colors",
  "commissioner",
  "unification",
  "semiconductor",
  "networking",
  "dumps",
  "disobedience",
  "priesthood",
  "genesis",
  "departure",
  "horror",
  "solitude",
  "viability",
  "vicinity",
  "bottlebrush",
  "flask",
  "lavender",
  "sharpness",
  "crocus",
  "deduction",
  "curfew",
  "daybreak",
  "retailer",
  "adage",
  "tossing",
  "sarcasm",
  "honesty",
  "grappling",
  "litre",
  "mobility",
  "sediment",
  "withholding",
  "onslaught",
  "lemur",
  "grocer",
  "metaphysics",
  "nursery",
  "licence",
  "delphinium",
  "saturday",
  "relaxation",
  "treadmill",
  "tuesday",
  "magnificence",
  "calamity",
  "operation",
  "staircase",
  "adoption",
  "witchcraft",
  "juncture",
  "inauguration",
  "environs",
  "celebrity",
  "chasm",
  "salvation",
  "driver",
  "ounce",
  "bowling",
  "illness",
  "basin",
  "inevitability",
  "rabbit",
  "squad",
  "quorum",
  "policeman",
  "exploitation",
  "provocation",
  "nobody",
  "ferret",
  "bedtime",
  "fulfillment",
  "wolverine",
  "manga",
  "wealth",
  "preoccupation",
  "grandeur",
  "mowing",
  "freesia",
  "certainty",
  "employment",
  "brightness",
  "probation",
  "stole",
  "tapir",
  "synopsis",
  "intercourse",
  "accountability",
  "posterity",
  "relativism",
  "jasmine",
  "burglary",
  "syrah",
  "ultimatum",
  "penguin",
  "roses",
  "commune",
  "differentiation",
  "inaccuracy",
  "donkey",
  "marjoram",
  "statement",
  "commenter",
  "tavern",
  "barrier",
  "hearts",
  "diploma",
  "miner",
  "whisky",
  "innovation",
  "hamster",
  "christianity",
  "hockey",
  "litigation",
  "narrator",
  "estimation",
  "parakeet",
  "mailing",
  "snapdragon",
  "publisher",
  "complexity",
  "headset",
  "scooter",
  "womanhood",
  "raccoon",
  "sunflower",
  "infiltration",
  "martyrdom",
  "duchess",
  "lily",
  "exaggeration",
  "violet",
  "somewhere",
  "ignition",
  "organisation",
  "stillness",
  "finale",
  "fixing",
  "cylinder",
  "oasis",
  "commander",
  "villa",
  "aardvark",
  "pairing",
  "heads",
  "babbling",
  "elephant",
  "ralph",
  "opposition",
  "mayor",
  "murderer",
  "juror",
  "subscription",
  "rhinoceros",
  "clearing",
  "staging",
  "sweepstakes",
  "tansy",
  "ligament",
  "memory",
  "fertilization",
  "immunization",
  "sloth",
  "camellias",
  "certification",
  "dismissal",
  "reptile",
  "absorption",
  "normalcy",
  "drilling",
  "traveler",
  "twenties",
  "shrew",
  "passenger",
  "gusto",
  "proceedings",
  "acceptance",
  "conversation",
  "semicolon",
  "appointment",
  "translation",
  "juggernaut",
  "iguana",
  "iris",
  "quilting",
  "appellation",
  "movie",
  "seriousness",
  "cheetah",
  "alpaca",
  "darkness",
  "ibex",
  "comer",
  "recurrence",
  "tights",
  "embroidery",
  "fascism",
  "mouthpiece",
  "bull",
  "baker",
  "browsing",
  "outset",
  "holly",
  "carnation",
  "billing",
  "senator",
  "stagnation",
  "attacker",
  "absence",
  "deficiency",
  "poster",
  "brunt",
  "cilantro",
  "scarcity",
  "refrigerator",
  "touchdown",
  "frog",
  "accessibility",
  "tempo",
  "foothold",
  "snapshot",
  "wiring",
  "biology",
  "uprising",
  "aversion",
  "adaptation",
  "orientalism",
  "appraisal",
  "salamander",
  "walrus",
  "apparatus",
  "distribution",
  "ticker",
  "vista",
  "contents",
  "downside",
  "architecture",
  "cow",
  "demon",
  "telephony",
  "bellflower",
  "fusion",
  "fries",
  "helping",
  "lilac",
  "deference",
  "dwelling",
  "enclosure",
  "coding",
  "prorogation",
  "fish",
  "thyme",
  "jackal",
  "misery",
  "illustration",
  "digger",
  "regulator",
  "puma",
  "advancement",
  "musician",
  "measurement",
  "consistency",
  "flashing",
  "panther",
  "joseph",
  "tracing",
  "prominence",
  "designation",
  "matrix",
  "offense",
  "forgiveness",
  "philosopher",
  "fastball",
  "archipelago",
  "formula",
  "soccer",
  "theology",
  "neighbour",
  "waistcoat",
  "negligence",
  "narcissus",
  "folklore",
  "rapidity",
  "matron",
  "anxiety",
  "collision",
  "windfall",
  "skate",
  "dominance",
  "mediator",
  "pundit",
  "chimpanzee",
  "resignation",
  "notification",
  "putting",
  "depletion",
  "lifeline",
  "atheism",
  "gunman",
  "larceny",
  "deliverance",
  "mantra",
  "orchestra",
  "endangerment",
  "earnings",
  "vomiting",
  "postponement",
  "headcount",
  "amaryllis",
  "verification",
  "bases",
  "allegation",
  "pounding",
  "genitals",
  "spectre",
  "innocence",
  "follower",
  "shoplifting",
  "transmission",
  "configuration",
  "radiance",
  "hoarding",
  "pendulum",
  "jogging",
  "consolidation",
  "cynicism",
  "begonia",
  "dispatcher",
  "aircraft",
  "arrears",
  "authority",
  "countdown",
  "editor",
  "archery",
  "glitter",
  "noodle",
  "reputation",
  "porcupine",
  "skunk",
  "daddy",
  "daisy",
  "crocodile",
  "pathos",
  "infamy",
  "catfish",
  "scrum",
  "sophistication",
  "yak",
  "daffodil",
  "marmoset",
  "freestyle",
  "groundwork",
  "boasting",
  "liquidation",
  "listener",
  "savior",
  "chili",
  "assignment",
  "workman",
  "riches",
  "wardrobe",
  "antelope",
  "motto",
  "breadth",
  "muskrat",
  "stamina",
  "lamb",
  "brainstorming",
  "mole",
  "lotus",
  "curator",
  "organizer",
  "capybara",
  "forefinger",
  "trauma",
  "spoiler",
  "therapy",
  "snead",
  "chinchilla",
  "saucer",
  "perusal",
  "thicket",
  "epilepsy",
  "cemetery",
  "panda",
  "basis",
  "nucleus",
  "voltage",
  "template",
  "sister",
  "mayhem",
  "cheesecake",
  "collaborator",
  "precedence",
  "method",
  "catholicism",
  "stocks",
  "anomaly",
  "height",
  "bonding",
  "insurer",
  "recreation",
  "widget",
  "blackberry",
  "lifeblood",
  "frenchman",
  "canonization",
  "jurisprudence",
  "fetish",
  "dingo",
  "criminality",
  "armadillo",
  "slipper",
  "underdog",
  "today",
  "definition",
  "monster",
  "columbine",
  "whale",
  "nylon",
  "mishap",
  "election",
  "clover",
  "finch",
  "brunch",
  "prospectus",
  "pointer",
  "inspiration",
  "nuisance",
  "paradox",
  "repentance",
  "scolding",
  "gladiolus",
  "dollar",
  "insanity",
  "chemotherapy",
  "commemoration",
  "civility",
  "falls",
  "plurality",
  "providence",
  "scenery",
  "consul",
  "orangutan",
  "dahlia",
  "morale",
  "standstill",
  "google",
  "bison",
  "hallway",
  "pullman",
  "dawning",
  "hegemony",
  "hierarchy",
  "mortality",
  "coverage",
  "recourse",
  "delegation",
  "jones",
  "lizard",
  "lustre",
  "brotherhood",
  "solemnity",
  "cabot",
  "righteousness",
  "quart",
  "owner",
  "apologise",
  "terror",
  "dromedary",
  "tyrant",
  "bounds",
  "polling",
  "appendix",
  "developer",
  "manufacturer",
  "patriotism",
  "speculation",
  "stairway",
  "concur",
  "viewpoint",
  "ram",
  "mimosa",
  "clothing",
  "leadership",
  "acquiescence",
  "schooner",
  "processing",
  "petunia",
  "apartheid",
  "helper",
  "equation",
  "doorstep",
  "gridlock",
  "simplicity",
  "hippopotamus",
  "permission",
  "rapport",
  "rocks",
  "servitude",
  "ankle",
  "effectiveness",
  "mandrill",
  "newt",
  "tablespoon",
  "agriculture",
  "hearth",
  "apostle",
  "delicacy",
  "cracker",
  "adjustment",
  "attractiveness",
  "fragmentation",
  "serenity",
  "bingo",
  "appeasement",
  "disservice",
  "opportunity",
  "footing",
  "reinforcement",
  "precinct",
  "cabal",
  "sesame",
  "prototype",
  "foxglove",
  "flora",
  "glamour",
  "clerk",
  "bones",
  "charade",
  "combustion",
  "competition",
  "heath",
  "rodeo",
  "diversity",
  "playing",
  "conflagration",
  "bodyguard",
  "quantity",
  "racism",
  "imperialism",
  "stoppage",
  "iteration",
  "projection",
  "eloquence",
  "neighborhood",
  "boar",
  "solicitation",
  "thistle",
  "comedian",
  "semifinal",
  "monument",
  "headquarters",
  "handshake",
  "tiger",
  "aggression",
  "parsley",
  "cassette",
  "pessimism",
  "plethora",
  "cholera"
]

ANIMALS = [
    "aardvark",
    "alligator",
    "alpaca",
    "antelope",
    "ape",
    "armadillo",
    "baboon",
    "badger",
    "bat",
    "bear",
    "beaver",
    "bison",
    "boar",
    "buffalo",
    "bull",
    "camel",
    "canary",
    "capybara",
    "cat",
    "chameleon",
    "cheetah",
    "chimpanzee",
    "chinchilla",
    "chipmunk",
    "cougar",
    "cow",
    "coyote",
    "crocodile",
    "crow",
    "deer",
    "dingo",
    "dog",
    "donkey",
    "dromedary",
    "elephant",
    "elk",
    "ewe",
    "ferret",
    "finch",
    "fish",
    "fox",
    "frog",
    "gazelle",
    "monster",
    "giraffe",
    "gnu",
    "goat",
    "gopher",
    "gorilla",
    "hamster",
    "hedgehog",
    "hippopotamus",
    "hog",
    "horse",
    "hyena",
    "ibex",
    "iguana",
    "impala",
    "jackal",
    "jaguar",
    "kangaroo",
    "koala",
    "lamb",
    "lemur",
    "leopard",
    "lion",
    "lizard",
    "llama",
    "lynx",
    "mandrill",
    "marmoset",
    "mink",
    "mole",
    "mongoose",
    "monkey",
    "moose",
    "mouse",
    "mule",
    "muskrat",
    "mustang",
    "bird",
    "newt",
    "ocelot",
    "opossum",
    "orangutan",
    "oryx",
    "otter",
    "ox",
    "panda",
    "panther",
    "parakeet",
    "parrot",
    "pig",
    "platypus",
    "porcupine",
    "porpoise",
    "puma",
    "rabbit",
    "raccoon",
    "ram",
    "rat",
    "reindeer",
    "reptile",
    "rhinoceros",
    "salamander",
    "seal",
    "sheep",
    "shrew",
    "skunk",
    "sloth",
    "snake",
    "squirrel",
    "tapir",
    "tiger",
    "toad",
    "turtle",
    "walrus",
    "warthog",
    "weasel",
    "whale",
    "wildcat",
    "wolf",
    "wolverine",
    "wombat",
    "woodchuck",
    "yak",
    "zebra"
]

FLOWERS = [
    "anemone",
    "amaryllis",
    "amaranth",
    "aster",
    "azalea",
    "begonia",
    "bellflower",
    "bergamot",
    "bluebell",
    "bottlebrush",
    "buttercup",
    "camellias",
    "carnation",
    "chrysantemum",
    "columbine",
    "clover",
    "crocus",
    "daisy",
    "dahlia",
    "daffodil",
    "delphinium",
    "edelweiss",
    "primrose",
    "foxglove",
    "freesia",
    "gladiolus",
    "hibiscus",
    "heather",
    "hyacinth",
    "holly",
    "iris",
    "jasmine",
    "slipper",
    "lavender",
    "lilac",
    "lily",
    "lotus",
    "marigold",
    "marjoram",
    "mimosa",
    "narcissus",
    "blossom",
    "orchid",
    "peony",
    "petunia",
    "rhododendron",
    "rosemary",
    "roses",
    "sage",
    "snapdragon",
    "sunflower",
    "tansy",
    "thistle",
    "thyme",
    "tulip",
    "violet",
    "lily",
    "zinnia"
]



import unittest
from unittest import mock

import hrid


class TestGenerateFunction(unittest.TestCase):

    def setUp(self):
        self.hrid = hrid.HRID()
        self.hrid.delimiter = ', '
        self.hrid.random = mock.Mock()
        self.hrid.random.choice.side_effect = lambda x: x[0]

    def test_transform_string_element(self):
        element = 'adjective'
        expected_output = hrid.word_lists.WORD_LISTS['adjective']
        self.assertEqual(self.hrid._transform_element(element), expected_output)

    def test_transform_list_element(self):
        element = ['hello', 'hi']
        self.assertEqual(self.hrid._transform_element(element), element)

    def test_transform_unknown_element(self):
        element = 'unknown'
        expected_output = [element]
        self.assertEqual(self.hrid._transform_element(element), expected_output)

    def test_string_elements_only(self):
        self.hrid._elements = [['hello'], ['world']]
        expected_output = 'hello, world'
        self.assertEqual(self.hrid.generate(), expected_output)

    def test_list_elements_only(self):
        self.hrid._elements = [['hello', 'hi'], ['world', 'earth']]
        expected_output = 'hello, world'
        self.assertEqual(self.hrid.generate(), expected_output)

    def test_mixed_string_and_list_elements(self):
        self.hrid._elements = [['hello'], ['world', 'earth'], ['again']]
        expected_output = 'hello, world, again'
        self.assertEqual(self.hrid.generate(), expected_output)

    def test_empty_elements(self):
        self.hrid._elements = []
        expected_output = ''
        self.assertEqual(self.hrid.generate(), expected_output)

    def test_none_elements(self):
        self.hrid._elements = None
        with self.assertRaises(TypeError):
            self.hrid.generate()


if __name__ == '__main__':
    unittest.main()



from hrid.word_lists.adjectives import ADJECTIVES
from hrid.word_lists.adverbs import ADVERBS
from hrid.word_lists.nouns import ANIMALS, FLOWERS, NOUNS
from hrid.word_lists.verbs import VERBS

WORD_LISTS = {
    'adjective': ADJECTIVES,
    'noun': NOUNS,
    'verb': VERBS,
    'adverb': ADVERBS,
    'animal': ANIMALS,
    'flower': FLOWERS,
    'number': [str(number) for number in range(10, 99)],
}



ADVERBS = [
    "abnormally",
    "absentmindedly",
    "accidentally",
    "acidly",
    "actually",
    "adventurously",
    "afterwards",
    "almost",
    "always",
    "angrily",
    "annually",
    "anxiously",
    "arrogantly",
    "awkwardly",
    "badly",
    "bashfully",
    "beautifully",
    "bitterly",
    "bleakly",
    "blindly",
    "blissfully",
    "boastfully",
    "boldly",
    "bravely",
    "briefly",
    "brightly",
    "briskly",
    "broadly",
    "busily",
    "calmly",
    "carefully",
    "carelessly",
    "cautiously",
    "certainly",
    "cheerfully",
    "clearly",
    "cleverly",
    "closely",
    "coaxingly",
    "colorfully",
    "commonly",
    "confidently",
    "continually",
    "coolly",
    "correctly",
    "courageously",
    "crazily",
    "crossly",
    "cruelly",
    "curiously",
    "daily",
    "daintily",
    "dearly",
    "deceivingly",
    "deeply",
    "defiantly",
    "deftly",
    "deliberately",
    "delightfully",
    "diligently",
    "dimly",
    "doubtfully",
    "dreamily",
    "dutifully",
    "eagerly",
    "easily",
    "elegantly",
    "energetically",
    "enormously",
    "enthusiastically",
    "equally",
    "especially",
    "even",
    "evenly",
    "eventually",
    "exactly",
    "excitedly",
    "extremely",
    "fairly",
    "faithfully",
    "famously",
    "far",
    "fast",
    "fatally",
    "ferociously",
    "fervently",
    "fiercely",
    "fondly",
    "foolishly",
    "fortunately",
    "frankly",
    "frantically",
    "freely",
    "frenetically",
    "frightfully",
    "fully",
    "furiously",
    "generally",
    "generously",
    "gently",
    "gladly",
    "gleefully",
    "gracefully",
    "gratefully",
    "greatly",
    "greedily",
    "happily",
    "hastily",
    "healthily",
    "heavily",
    "helpfully",
    "helplessly",
    "highly",
    "honestly",
    "hopelessly",
    "hourly",
    "hungrily",
    "immediately",
    "innocently",
    "inquisitively",
    "instantly",
    "intensely",
    "intently",
    "interestingly",
    "inwardly",
    "irritably",
    "jaggedly",
    "jealously",
    "joshingly",
    "jovially",
    "joyfully",
    "joyously",
    "jubilantly",
    "judgementally",
    "justly",
    "keenly",
    "kiddingly",
    "kindheartedly",
    "kindly",
    "kissingly",
    "knavishly",
    "knottily",
    "knowingly",
    "knowledgeably",
    "kookily",
    "lazily",
    "less",
    "lightly",
    "likely",
    "limply",
    "lively",
    "loftily",
    "longingly",
    "loosely",
    "loudly",
    "lovingly",
    "loyally",
    "madly",
    "majestically",
    "meaningfully",
    "mechanically",
    "merrily",
    "miserably",
    "mockingly",
    "monthly",
    "more",
    "mortally",
    "mostly",
    "mysteriously",
    "naturally",
    "nearly",
    "neatly",
    "needily",
    "nervously",
    "never",
    "nicely",
    "noisily",
    "not",
    "obediently",
    "obnoxiously",
    "oddly",
    "offensively",
    "officially",
    "often",
    "only",
    "openly",
    "optimistically",
    "originally",
    "overconfidently",
    "owlishly",
    "painfully",
    "partially",
    "patiently",
    "perfectly",
    "physically",
    "playfully",
    "politely",
    "poorly",
    "positively",
    "potentially",
    "powerfully",
    "promptly",
    "properly",
    "punctually",
    "quaintly",
    "quarrelsomely",
    "queasily",
    "queerly",
    "questionably",
    "questioningly",
    "quicker",
    "quickly",
    "quietly",
    "quirkily",
    "quizzically",
    "rapidly",
    "rarely",
    "readily",
    "really",
    "reassuringly",
    "recklessly",
    "regularly",
    "reluctantly",
    "repeatedly",
    "reproachfully",
    "restfully",
    "righteously",
    "rightfully",
    "rigidly",
    "roughly",
    "rudely",
    "sadly",
    "safely",
    "scarcely",
    "scarily",
    "searchingly",
    "sedately",
    "seemingly",
    "seldom",
    "selfishly",
    "separately",
    "seriously",
    "shakily",
    "sharply",
    "sheepishly",
    "shrilly",
    "shyly",
    "silently",
    "sleepily",
    "slightly",
    "slowly",
    "smoothly",
    "softly",
    "solemnly",
    "solidly",
    "sometimes",
    "somewhat",
    "soon",
    "speedily",
    "stealthily",
    "sternly",
    "strictly",
    "successfully",
    "suddenly",
    "surprisingly",
    "suspiciously",
    "sweetly",
    "swiftly",
    "sympathetically",
    "tediously",
    "tenderly",
    "tensely",
    "terribly",
    "thankfully",
    "thoroughly",
    "thoughtfully",
    "tightly",
    "tomorrow",
    "too",
    "tremendously",
    "triumphantly",
    "truly",
    "truthfully",
    "ultimately",
    "unabashedly",
    "unaccountably",
    "unbearably",
    "unethically",
    "unexpectedly",
    "unfortunately",
    "unimpressively",
    "unnaturally",
    "unnecessarily",
    "upbeat",
    "upliftingly",
    "upright",
    "upward",
    "upwardly",
    "urgently",
    "usefully",
    "uselessly",
    "usually",
    "utterly",
    "vacantly",
    "vaguely",
    "vainly",
    "valiantly",
    "vastly",
    "verbally",
    "very",
    "viciously",
    "victoriously",
    "violently",
    "virtually",
    "vivaciously",
    "voluntarily",
    "warmly",
    "weakly",
    "wearily",
    "well",
    "wetly",
    "wholly",
    "wildly",
    "willfully",
    "wisely",
    "woefully",
    "wonderfully",
    "worriedly",
    "wrongly",
    "yawningly",
    "yearly",
    "yearningly",
    "yesterday",
    "yieldingly",
    "youthfully"
]



import random
from typing import Iterable, Optional

from hrid.word_lists import WORD_LISTS


class HRID:
    DEFAULT_ELEMENTS = ('adjective', 'noun', 'verb', 'adverb')

    def __init__(self, delimiter: str = '-', elements: Iterable[str] = None,
                 seed: Optional[int | float | str | bytes | bytearray] = None) -> None:
        """
        Initializes the HRID instance with a specified delimiter, elements, and random seed.

        :param delimiter: The string used to join the elements of the generated ID.
        :param elements: An iterable of strings specifying the types of words to include in the ID.
                         If not specified, DEFAULT_ELEMENTS will be used.
        :param seed: An optional seed for the random number generator to ensure reproducibility.
                     Accepts int, float, str, bytes, or bytearray.

        :return: None
        """
        self.delimiter = delimiter
        self.random = random.Random(seed)
        elements = elements or self.DEFAULT_ELEMENTS
        self._elements = [self._transform_element(e) for e in elements]

    @staticmethod
    def _transform_element(element: str | list[str]) -> list[str]:
        """
        Transforms an element into a list of words.

        If the element is a string present in WORD_LISTS, it will be replaced by the list of words
        associated with that string.

        If the element is a string, it will be wrapped in a list.

        Otherwise, the element is returned unchanged.

        :param element: The element to transform.
        :return: A list of words.
        """
        if isinstance(element, str):
            if element in WORD_LISTS:
                return WORD_LISTS[element]
            return [element]
        return element

    def generate(self):
        """
        Generates a human-readable ID by randomly selecting one word from each of the elements.

        The elements are specified during initialization, and each element is transformed into a list of
        words by the _transform_element method. The words are then joined together with the delimiter
        specified during initialization.

        :return: A string representing a human-readable ID
        """
        words = [self.random.choice(e) for e in self._elements]
        return self.delimiter.join(words)
